"""Main library for pylc3."""
__author__ = """Brandon Whitehead"""
__email__ = 'brandon.whitehead@gatech.edu'
__version__ = '0.1.5'

from .core import LC3State
from .core import MemoryFillStrategy